@@ -1,7 +1,7 @@
 """
 Type annotations for ce service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html)
+[Open documentation](./client.md)
 
 Usage::
 
@@ -17,7 +17,7 @@ from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_ce.literals import (
+from .literals import (
     AccountScope,
     AnomalyFeedbackType,
     AnomalySubscriptionFrequency,
@@ -31,7 +31,7 @@ from mypy_boto3_ce.literals import (
     SupportedSavingsPlansType,
     TermInYears,
 )
-from mypy_boto3_ce.type_defs import (
+from .type_defs import (
     AnomalyDateIntervalTypeDef,
     AnomalyMonitorTypeDef,
     AnomalySubscriptionTypeDef,
@@ -107,8 +107,8 @@ class Exceptions:
 
 class CostExplorerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -116,24 +116,24 @@ class CostExplorerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can-paginate)
         """
 
     def create_anomaly_monitor(
         self, AnomalyMonitor: "AnomalyMonitorTypeDef"
     ) -> CreateAnomalyMonitorResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create-anomaly-monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
+        [Show boto3-stubs documentation](./client.md#create-anomaly-monitor)
         """
 
     def create_anomaly_subscription(
         self, AnomalySubscription: "AnomalySubscriptionTypeDef"
     ) -> CreateAnomalySubscriptionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create-anomaly-subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
+        [Show boto3-stubs documentation](./client.md#create-anomaly-subscription)
         """
 
     def create_cost_category_definition(
@@ -144,36 +144,36 @@ class CostExplorerClient:
         DefaultValue: str = None,
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create-cost-category-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Show boto3-stubs documentation](./client.md#create-cost-category-definition)
         """
 
     def delete_anomaly_monitor(self, MonitorArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete-anomaly-monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
+        [Show boto3-stubs documentation](./client.md#delete-anomaly-monitor)
         """
 
     def delete_anomaly_subscription(self, SubscriptionArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete-anomaly-subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
+        [Show boto3-stubs documentation](./client.md#delete-anomaly-subscription)
         """
 
     def delete_cost_category_definition(
         self, CostCategoryArn: str
     ) -> DeleteCostCategoryDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete-cost-category-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Show boto3-stubs documentation](./client.md#delete-cost-category-definition)
         """
 
     def describe_cost_category_definition(
         self, CostCategoryArn: str, EffectiveOn: str = None
     ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#describe-cost-category-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Show boto3-stubs documentation](./client.md#describe-cost-category-definition)
         """
 
     def generate_presigned_url(
@@ -184,8 +184,8 @@ class CostExplorerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
         """
 
     def get_anomalies(
@@ -198,16 +198,16 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetAnomaliesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_anomalies)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-anomalies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_anomalies)
+        [Show boto3-stubs documentation](./client.md#get-anomalies)
         """
 
     def get_anomaly_monitors(
         self, MonitorArnList: List[str] = None, NextPageToken: str = None, MaxResults: int = None
     ) -> GetAnomalyMonitorsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-anomaly-monitors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
+        [Show boto3-stubs documentation](./client.md#get-anomaly-monitors)
         """
 
     def get_anomaly_subscriptions(
@@ -218,8 +218,8 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetAnomalySubscriptionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-anomaly-subscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
+        [Show boto3-stubs documentation](./client.md#get-anomaly-subscriptions)
         """
 
     def get_cost_and_usage(
@@ -232,8 +232,8 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetCostAndUsageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-cost-and-usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Show boto3-stubs documentation](./client.md#get-cost-and-usage)
         """
 
     def get_cost_and_usage_with_resources(
@@ -246,8 +246,8 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-cost-and-usage-with-resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Show boto3-stubs documentation](./client.md#get-cost-and-usage-with-resources)
         """
 
     def get_cost_categories(
@@ -261,8 +261,8 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetCostCategoriesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-cost-categories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
+        [Show boto3-stubs documentation](./client.md#get-cost-categories)
         """
 
     def get_cost_forecast(
@@ -274,8 +274,8 @@ class CostExplorerClient:
         PredictionIntervalLevel: int = None,
     ) -> GetCostForecastResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-cost-forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Show boto3-stubs documentation](./client.md#get-cost-forecast)
         """
 
     def get_dimension_values(
@@ -290,8 +290,8 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetDimensionValuesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-dimension-values)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Show boto3-stubs documentation](./client.md#get-dimension-values)
         """
 
     def get_reservation_coverage(
@@ -306,8 +306,8 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetReservationCoverageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-reservation-coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Show boto3-stubs documentation](./client.md#get-reservation-coverage)
         """
 
     def get_reservation_purchase_recommendation(
@@ -324,8 +324,8 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-reservation-purchase-recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Show boto3-stubs documentation](./client.md#get-reservation-purchase-recommendation)
         """
 
     def get_reservation_utilization(
@@ -339,8 +339,8 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetReservationUtilizationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-reservation-utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Show boto3-stubs documentation](./client.md#get-reservation-utilization)
         """
 
     def get_rightsizing_recommendation(
@@ -352,8 +352,8 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetRightsizingRecommendationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-rightsizing-recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Show boto3-stubs documentation](./client.md#get-rightsizing-recommendation)
         """
 
     def get_savings_plans_coverage(
@@ -368,8 +368,8 @@ class CostExplorerClient:
         SortBy: SortDefinitionTypeDef = None,
     ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-savings-plans-coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Show boto3-stubs documentation](./client.md#get-savings-plans-coverage)
         """
 
     def get_savings_plans_purchase_recommendation(
@@ -384,8 +384,8 @@ class CostExplorerClient:
         Filter: "ExpressionTypeDef" = None,
     ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-savings-plans-purchase-recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Show boto3-stubs documentation](./client.md#get-savings-plans-purchase-recommendation)
         """
 
     def get_savings_plans_utilization(
@@ -396,8 +396,8 @@ class CostExplorerClient:
         SortBy: SortDefinitionTypeDef = None,
     ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-savings-plans-utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Show boto3-stubs documentation](./client.md#get-savings-plans-utilization)
         """
 
     def get_savings_plans_utilization_details(
@@ -410,8 +410,8 @@ class CostExplorerClient:
         SortBy: SortDefinitionTypeDef = None,
     ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-savings-plans-utilization-details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Show boto3-stubs documentation](./client.md#get-savings-plans-utilization-details)
         """
 
     def get_tags(
@@ -425,8 +425,8 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetTagsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_tags)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Show boto3-stubs documentation](./client.md#get-tags)
         """
 
     def get_usage_forecast(
@@ -438,32 +438,32 @@ class CostExplorerClient:
         PredictionIntervalLevel: int = None,
     ) -> GetUsageForecastResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-usage-forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Show boto3-stubs documentation](./client.md#get-usage-forecast)
         """
 
     def list_cost_category_definitions(
         self, EffectiveOn: str = None, NextToken: str = None, MaxResults: int = None
     ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#list-cost-category-definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Show boto3-stubs documentation](./client.md#list-cost-category-definitions)
         """
 
     def provide_anomaly_feedback(
         self, AnomalyId: str, Feedback: AnomalyFeedbackType
     ) -> ProvideAnomalyFeedbackResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#provide-anomaly-feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
+        [Show boto3-stubs documentation](./client.md#provide-anomaly-feedback)
         """
 
     def update_anomaly_monitor(
         self, MonitorArn: str, MonitorName: str = None
     ) -> UpdateAnomalyMonitorResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update-anomaly-monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
+        [Show boto3-stubs documentation](./client.md#update-anomaly-monitor)
         """
 
     def update_anomaly_subscription(
@@ -476,8 +476,8 @@ class CostExplorerClient:
         SubscriptionName: str = None,
     ) -> UpdateAnomalySubscriptionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update-anomaly-subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
+        [Show boto3-stubs documentation](./client.md#update-anomaly-subscription)
         """
 
     def update_cost_category_definition(
@@ -488,6 +488,6 @@ class CostExplorerClient:
         DefaultValue: str = None,
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update-cost-category-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Show boto3-stubs documentation](./client.md#update-cost-category-definition)
         """
